/* dopewars.h  Common structures and stuff for Dopewars                 */
/* Copyright (C)  1998-9  Ben Webb                                      */
/*                Email: ben@bellatrix.pcl.ox.ac.uk                     */
/*                WWW: http://bellatrix.pcl.ox.ac.uk/~ben/dopewars/     */

/* This program is free software; you can redistribute it and/or        */
/* modify it under the terms of the GNU General Public License          */
/* as published by the Free Software Foundation; either version 2       */
/* of the License, or (at your option) any later version.               */

/* This program is distributed in the hope that it will be useful,      */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of       */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        */
/* GNU General Public License for more details.                         */

/* You should have received a copy of the GNU General Public License    */
/* along with this program; if not, write to the Free Software          */
/* Foundation, Inc., 59 Temple Place - Suite 330, Boston,               */
/*                   MA  02111-1307, USA.                               */


#ifndef __DOPEWARS_H__
#define __DOPEWARS_H__

#include <stdio.h>
#include <ncurses.h>

extern int ClientSock,ListenSock;
extern char Network,Client,Server,AIPlayer;
extern int Port;
extern FILE *out;
extern int NUMLOCATION;
extern char HiScoreFile[80],ServerName[80];
extern char WantHelp,WantVersion,WantAntique,WantColour,WantNetwork;

#define MAXTURNS     31
#define BUFLEN       600
#define NUMDRUG      12
#define MAXLOCATION  8
#define NUMSUBWAY    31
#define NUMHISCORE   18
#define NUMGUN       4
#define NUMSTOPPEDTO 5
#define NUMPLAYING   18
#define NUMDISCOVER  3

#define ESCAPE  0
#define DEFECT  1
#define SHOT    2

#define MINBITCHPRICE 50000
#define MAXBITCHPRICE 150000

#define MINTRENCHPRICE 200
#define MAXTRENCHPRICE 300

#define ACID    0
#define COCAINE 1
#define HASHISH 2
#define HEROIN  3
#define LUDES   4
#define MDA     5
#define OPIUM   6
#define PCP     7
#define PEYOTE  8
#define SHROOMS 9
#define SPEED   10 
#define WEED    11

#define LOANSHARK 0
#define BANK      0
#define GUNSHOP   1
#define ROUGHPUB  1

#define VERSION 1
#define MAJVER  4
#define MINVER  1

#define FIRSTTURN   1
#define DEADHARDASS 2
#define TIPPEDOFF   4
#define SPIEDON     8
#define SPYINGON    16
#define FIGHTING    32

#define LISTONLY    0
#define PAGETO      1
#define SELECTTIP   2
#define SELECTSPY   3

#define F_STAND     0
#define F_FIGHT     1
#define F_RUN       2

#define E_NONE       0
#define E_SUBWAY     1
#define E_COPOFFER   2
#define E_OFFOBJECT  3
#define E_DOCTOR     4
#define E_WEED       5
#define E_SAYING     6
#define E_LOANSHARK  7
#define E_BANK       8
#define E_GUNSHOP    9
#define E_ROUGHPUB   10
#define E_HIREBITCH  11
#define E_ARRIVE     12
#define E_MAX        13

#define E_FINISH     100

#define E_OUTOFSYNC  120
#define E_ATTACK     121
#define E_WAITFIGHT  122
#define E_DEFEND     123
#define E_MAXOOS     124

#define SPYPRICE   20000
#define TIPPRICE   10000

#define PromptAttr   (COLOR_PAIR(1))
#define TextAttr     (COLOR_PAIR(2))
#define LocationAttr (COLOR_PAIR(3)|A_BOLD)
#define TitleAttr    (COLOR_PAIR(4))
#define StatsAttr    (COLOR_PAIR(5))
#define DebtAttr     (COLOR_PAIR(6))

struct GUN {
   char Name[80];
   int Price;
   int Space;
   int Damage;
};
extern struct GUN Gun[NUMGUN];

struct HISCORE {
   char Time[80];
   long Money;
   char Dead;
   char Name[80];
};

struct LOCATION {
   char Name[30];
   char PolicePresence;
   int MinDrug,MaxDrug;
};
extern struct LOCATION Location[MAXLOCATION];

struct DRUG {
   char Name[30];
   int MinPrice;
   int MaxPrice;
   char SpecLow,SpecHigh;
   int Current,Max;
   char Done;
};
extern struct DRUG Drug[NUMDRUG];

struct INVENTORY {
   int Gun[NUMGUN];
   int Drug[NUMDRUG];
};
typedef struct INVENTORY Inventory;

struct TDrugHere {
   int Price[NUMDRUG];
   int Deal[NUMDRUG];    /* 1="addicts are buying"  2="big bust" */
};
typedef struct TDrugHere DrugHere;   

struct PLAYER;
struct TDopeEntry {
   struct PLAYER *Play;
   int Turns;
};
typedef struct TDopeEntry DopeEntry;

struct TDopeList {
   DopeEntry *Data;
   int Number;
};
typedef struct TDopeList DopeList;

struct PLAYER {
   char Turn;
   long Cash,Debt,Bank;
   char Health;
   int CoatSize;
   char IsAt;
   Inventory Carry,OnGround;
   struct PLAYER *Attacked;
   char Flags;
   char Bitches;
   char Name[80];
   struct PLAYER *Next;
   int fd;
   FILE *out;
   int EventNum,ResyncNum;
   int DamageDone;
   DrugHere *Here;
   long BitchPrice;
   int GunPrice[NUMGUN];
   int Cops;
   int DocPrice;
   DopeList SpyList;
   DopeList TipList;
   struct PLAYER *OnBehalfOf;
};
extern struct PLAYER *Player,Noone;
extern char *Discover[NUMDISCOVER];
extern char *Playing[NUMPLAYING];
extern char *SubwaySaying[NUMSUBWAY];
extern char *StoppedTo[NUMSTOPPEDTO];

void RemovePlayer(struct PLAYER *Play,struct PLAYER **First);
struct PLAYER *GetPlayerByName(char *Name,struct PLAYER *First);
struct PLAYER *AddPlayer(int fd,struct PLAYER **First);
char IsValidPlayer(struct PLAYER *Play,struct PLAYER *First);
void clear_bottom();
void clear_exceptfor(int skip);
void nice_wait();
void InitialisePlayer(struct PLAYER *Play);
void ClearInventory(Inventory *Inven);
int IsCarryingRandom(struct PLAYER *Play,int amount);
void InitList(DopeList *List);
void AddListEntry(DopeList *List,DopeEntry *NewEntry);
void RemoveListEntry(DopeList *List,int Entry);
int GetListEntry(DopeList *List,struct PLAYER *Play);
void RemoveListPlayer(DopeList *List,struct PLAYER *Play);
void ClearList(DopeList *List);
struct PLAYER *ListPlayers(struct PLAYER *Play,char Select,char *Prompt);
void clear_line(int line);
int TotalGunsCarried(struct PLAYER *Player);
int read_string(FILE *fp,char *buf,int maxlen);
int brandom(int bot,int top);
void display_message(char *buf);
void print_location(char *text);
int GetKey(char *allowed);
void AddInventory(Inventory *Cumul,Inventory *Add);
void TruncateInventoryFor(Inventory *Inven,struct PLAYER *Play);
void PrintInventory(Inventory *Inven);
void DisplaySpyReports(char *Data,struct PLAYER *From);
void change_name(char nullname);
void clear_screen();
char *FormatPrice(long price,char *buffer);
void nice_input(char *prompt,char *str,int maxlen,int sy,int sx,
                char digitsonly,char displaystr);
char IsInventoryClear(Inventory *Inven);
void print_status(struct PLAYER *Play,char DispDrug);

#endif
